@@ -1,3 +1,5 @@
+from asyncio.exceptions import CancelledError
+
 from starlette.datastructures import MutableHeaders
 from starlette.templating import Jinja2Templates
 
@@ -20,7 +22,10 @@ class ExtraResponseHeadersMiddleware:
 
             await send(message)
 
-        await self.app(scope, receive, send_with_extra_headers)
+        try:
+            await self.app(scope, receive, send_with_extra_headers)
+        except CancelledError:
+            pass
 
 
 class TemplateResponseFactory(Jinja2Templates):
